<?php

    class Infusionsoft_Settings {

        private $settings = array();
        
        public function __construct()
        {
            add_action('admin_init', array($this, 'init'));
            add_action('admin_menu', array($this, 'menu'));
        }

        /**
         * Sets up the plugin by adding the settings link on the GF Settings page
         */
        public function init()
        {
            register_setting('infusionsoft_settings', 'infusionsoft_settings', array($this, 'validate'));

            add_settings_section('infusionsoft_api', 'Infusionsoft API Settings', array($this, 'api_settings'), 'pdftoisoft');
            add_settings_field('app_name', 'App ID (Subdomain)', array($this, 'get_app_name'), 'pdftoisoft', 'infusionsoft_api');
           // add_settings_field('app_api_key', 'App API Key', array($this, 'get_app_api_key'), 'pdftoisoft', 'infusionsoft_api');
	        add_settings_field('path_to_sdk', 'Path to SDK', array($this, 'get_path_to_sdk'), 'pdftoisoft', 'infusionsoft_api');
	       // add_settings_field('connection_name', 'Connection Name', array($this, 'get_connection_name'), 'pdftoisoft', 'infusionsoft_api');
            
            add_settings_section('gravity_settings', 'GravityForm Settings', array($this, 'gravity_settings'), 'pdftoisoft');
            add_settings_field('allowed_gravity_forms', 'Allowed Gravity Forms', array($this, 'get_allowed_gravity_forms'), 'pdftoisoft', 'gravity_settings');
        }

        /**
         * Adds a link to the Infusionsoft to the Settings menu
         */
        public function menu()
        {
            add_options_page('PDF to Infusionsoft', 'PDF to Infusionsoft', 'manage_options', 'infusionsoft-api', array($this, 'settings_page'));
        }
        
        /**
         * Displays the subdomain settings field
         */
        public function get_app_name()
        {
            $this->get_settings();
            
            $app_name = (isset($this->settings['app_name']) ? $this->settings['app_name'] : '');
            
            $this->render_text_input('app_name', $app_name);
        }

        /**
         * Displays the API key settings field
         */
        // public function get_app_api_key()
        // {
            // $this->get_settings();
//             
            // $app_api_key = (isset($this->settings['app_api_key']) ? $this->settings['app_api_key'] : '');
//             
            // $this->render_text_input('app_api_key', $app_api_key);
        // }

        /**
         * Displays the SDK path settings field
         */
        public function get_path_to_sdk()
        {
            $this->get_settings();
            
            $path_to_sdk = (isset($this->settings['path_to_sdk']) ? $this->settings['path_to_sdk'] : '');
            
            $this->render_text_input('path_to_sdk', $path_to_sdk);
        }
        


        /**
         * Displays the connection name settings field
         */
        // public function get_connection_name()
        // {
            // $this->get_settings();
//             
            // $connection_name = (isset($this->settings['connection_name']) ? $this->settings['connection_name'] : '');
//             
            // $this->render_text_input('connection_name', $connection_name);
        // }


        /**
         * Display an input box to list the whitelisted Gravity form IDs
         */
        public function get_allowed_gravity_forms()
        {
            $this->get_settings();
            
            $allowed_gravity_forms = (isset($this->settings['allowed_gravity_forms']) ? $this->settings['allowed_gravity_forms'] : '');
            
            $this->render_text_input('allowed_gravity_forms', $allowed_gravity_forms, 'Comma separated list of gravity form IDs');
        }
        
        /**
         * Callback for the API settings section, which is left blank
         */
        public function api_settings() { }
        
        /**
         * Callback for the integration settings section, which is left blank
         */
        public function gravity_settings() { }
        
        /**
         * Local helper function for loading settings
         *
         * @access private
         */
        private function get_settings()
        {
            $this->settings = (array)get_option('infusionsoft_settings');
        }
        
        /**
         * Local helper function for rendering input text fields
         *
         * @access private
         */
        private function render_text_input($name, $value = '', $tooltip_text = '')
        {
            echo '<input type="text" size="40" name="infusionsoft_settings[' . $name . ']" value="' . esc_attr($value) . '" />' . ($tooltip_text ? "<br /><span style=\"font-size: 9pt;\">{$tooltip_text}</span>" : '');
        }
        
        /**
         * Validates the user input
         * @param  array $input POST data
         * @return array        Sanitized POST data
         */
        public function validate($input)
        {   
	    
            // try
            // {
                // require_once '/scripts/isdk.php';
                // $infusionsoft = new iSDK();
//                 
                // if ( ! $infusionsoft->cfgCon($input['connection_name']))
                // {
                    // throw new Exception();
                // }
            // }
            // catch (Exception $e)
            // {
                // add_settings_error(
                    // 'infusionsoft_api',
                    // 'invalid-credentials',
                    // 'An error occurred while validating your Infusionsoft credentials. Please double-check your details and try again.'
                // );
            // };
            
            if (isset($input['allowed_gravity_forms']))
            {
                $input['allowed_gravity_forms'] = rtrim(preg_replace('/[^0-9, ]/', '', $input['allowed_gravity_forms']), ',');
            }
            
            if (get_settings_errors())
            {
                $input = array_merge(get_option('infusionsoft_settings'), array('allowed_gravity_forms' => $input['allowed_gravity_forms']));
                
                file_put_contents($config_file, $preserve);
            }
            
            $input = array_map('esc_html', $input);
            
            return $input;
        }

        /**
         * Output the main settings page with the title and form
         */
        public function settings_page()
        {

?>
<div class="wrap" style="margin: 0px; padding: 0px;">
<div id="icon-options-general" class="icon32"><br /></div>
<br />
<h2 style="margin-bottom: 20px;">Gravity Forms PDF to Infusionsoft Filebox</h2>
<div class="updated" style="border-left: 4px solid orange;">
<p>
<strong>Notice:</strong> This plugin requires that both Gravity Forms and Gravity Forms PDF Extended be installed.
</p>
</div>
<form method="POST" action="options.php">
<?php
settings_fields('infusionsoft_settings');
do_settings_sections('pdftoisoft');
submit_button();
?>
</form>
</div>
<?php
}
}

$infusionsoft_settings = new Infusionsoft_Settings;
