<?php
/**
 * Plugin Name: Gravity Forms PDF to Infusionsoft
 * Plugin URI: http://theapiguys.com
 * Description: Send Gravity Forms output to Infusionsoft
 * Version: 0.2
 * Author: Justin Handley - The API Guys
 * License: GPL2
 */

$settings = (array)get_option('infusionsoft_settings');
if ($settings['path_to_sdk']) {
    require_once ABSPATH . $settings['path_to_sdk'];
}
require_once plugin_dir_path(__FILE__) . 'infusionsoft-settings.php';
require_once ABSPATH . '/wp-admin/includes/plugin.php';

class PDF_to_infusionsoft {

    const EMAIL_FIELD = 1;

    /**
     * Call all actions and hooks used by the plugi
     */
    public function __construct() {
        add_action('gform_after_submission', array($this, 'handle_file'), 12, 2);
    }

    public function handle_file($entry, $form) {
        $settings = (array)get_option('infusionsoft_settings');
        if (!$settings['app_name']) {
            echo 'There has been an error.  Please check your settings';
            die ;
        }
        /*
         * Only work with whitelisted Gravity forms
         */
        if (!in_array((int)$entry['form_id'], array_map('intval', explode(',', rtrim(preg_replace('/[^0-9,]/', '', $settings['allowed_gravity_forms']), ','))))) {
            return;
        }

        if (class_exists('iSDK')) {
            $infusionsoft = new iSDK();

            if (!$infusionsoft -> cfgCon($settings['app_name'])) {
                /*
                 * Send notice to admin?
                 */
                return;
            }

            $contact = $infusionsoft -> dsQuery('Contact', 1, 0, array('Email' => $entry[self::EMAIL_FIELD]), array('Id'));

            if (!$contact) {
                /*
                 * Send notice to admin?
                 */
                return;
            }

            $contact = $contact[0]['Id'];

            /*
             * Get base64 encoded PDF file contents
             */
            $location = get_stylesheet_directory_uri() . "/PDF_EXTENDED_TEMPLATES/output/{$entry['form_id']}{$entry['id']}/form-{$entry['form_id']}-entry-{$entry['id']}.pdf";
            $contents = base64_encode(file_get_contents($location));
            $filename = 'Contract_' . date('Y-m-d\_H:i:s') . '.pdf';

            /*
             * Upload file to Infusionsoft FileBox; on failure, custom handler
             */
            if (!$infusionsoft -> uploadFile($filename, $contents, $contact)) {
                /*
                 * Send notice to admin?
                 */
                die ;
            }
        }
    }

}

$pdf_to_infusionsoft = new PDF_to_infusionsoft();
